<?php
require_once __DIR__ . '/../../lib/class.db.php';
require_once __DIR__ . '/../../lib/class.portal.php';
require_once __DIR__ . '/../../vendor/autoload.php';

use RhdEvents\Portal as Portal;

session_start();

$db = new \RhdEvents\Db();


if (isset($_REQUEST['action'])) {
    $action = $_REQUEST['action'];

    switch ($action) {
        case 'add':
            //
            $insertResult = $db->insert('workers', [
                'first_name'        =>  $_REQUEST['first_name'],
                'last_name'         =>  $_REQUEST['last_name'],
                //'email'             =>  $_REQUEST['email'],
            ]);
            try {
                $db->wasActionSuccessful($insertResult);
                Portal::addFlashMessage("Successfully added this staff member", 'success');
            } catch (\Exception $e) {
                Portal::addFlashMessage("DB error: " . $e->getMessage(), 'danger');
            }
            break;
        case 'edit':
            // edit
            $updateResult = $db->update('workers', [
                'first_name'        =>  $_REQUEST['first_name'],
                'last_name'         =>  $_REQUEST['last_name'],
                //'email'             =>  $_REQUEST['email'],
            ], [
                'worker_id'         =>  $_REQUEST['worker_id']
            ]);
            try {
                $db->wasActionSuccessful($updateResult);
                Portal::addFlashMessage("Successfully updated this staff member", 'success');
            } catch (\Exception $e) {
                Portal::addFlashMessage("DB error: " . $e->getMessage(), 'danger');
            }
            break;
        case 'delete':
            // delete
            $deleteResult = $db->delete('workers', [
                'worker_id'     =>  $_REQUEST['worker_id']
            ]);
            try {
                $db->wasActionSuccessful($deleteResult);
                Portal::addFlashMessage("Successfully deleted this staff member", 'success');
            } catch (\Exception $e) {
                Portal::addFlashMessage("DB error: " . $e->getMessage(), 'danger');
            }
            break;
        default:
            //
            Portal::addFlashMessage("Could not find this action", 'danger');
    }
}
require_once __DIR__ . '/../../lib/inc.header.php';
?>

    <div class='row'>
        <table class='table'>
            <thead>
                <tr>
                    <th>ID</th>
                    <th>First name</th>
                    <th>Last name</th>
                    <th>Email name</th>
                    <th>Edit</th>
                </tr>
            </thead>
            <tbody>
<?php
$workers = $db->select('workers', '*', ['active' => true]);
if (empty($workers)) {
    ?>
                <tr>
                    <td colspan='100' class='text-center'>No Workers</td>
                </tr>
<?php
}
else {
    foreach($workers as $workerRow) {
        ?>
                <tr>
                    <td data-field='worker_id'><?= $workerRow['worker_id'] ?></td>
                    <td data-field='first_name'><?= $workerRow['first_name'] ?></td>
                    <td data-field='last_name'><?= $workerRow['last_name'] ?></td>
                    <td data-field='email'><?= $workerRow['email'] ?></td>
                    <td>
                        <a href='#' class='edit-staff btn btn-primary btn-xs' data-toggle="modal" data-target="#edit-create-modal">Edit</a><br/>
                        <a href='#' class='delete-staff btn btn-danger btn-xs'>Delete</a>
                    </td>
                </tr>
        <?php
    }
    ?>

    <?php
}
?>

            </tbody>
        </table>
    </div>

    <div class='row'>
        <div class='col-xs-12 col-md-6 col-md-offset-3 text-center'>
            <button id='add-staff' class='btn btn-primary' data-toggle="modal" data-target="#edit-create-modal">Add Staff</button>
        </div>
    </div>
    
</div>

<form method='POST' id='delete_staff_form'>
    <input type='hidden' name='action' value='delete' />
    <input type='hidden' name='worker_id' id='delete_worker_id' value='' />
</form>
<!-- Modal -->
<div id="edit-create-modal" class="modal fade" role="dialog">
  <div class="modal-dialog">

    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal">&times;</button>
        <h4 class="modal-title">Edit</h4>
      </div>
      <div class="modal-body">
      <div class='row'>
        <div class='col-xs-12 col-md-8 col-md-offset-2'>
            <!-- <h2 class='text-center'>Edit</h2> -->
            <form method='POST' id='edit_staff_form'>
                <input type='hidden' id='edit_staff_action' name='action' value='edit' />
                <input type='hidden' id='edit_staff_id' name='worker_id' value='' />
                <div class='form-group'>
                    <label>First name</label>
                    <input type='text' class='form-control' name='first_name' />
                </div>
                
                <div class='form-group'>
                    <label>Last name</label>
                    <input type='text' class='form-control' name='last_name' />
                </div>
                
                <!--
                <div class='form-group'>
                    <label>Email</label>
                    <input type='text' class='form-control' name='email' />
                </div>
                -->

                <div class='text-center'>
                    <button class='btn btn-success btn-lg'>Submit</button>
                    <button class='btn btn-danger btn-lg' data-dismiss='modal'>Cancel</button>
                </div>
            </form>
        </div>
    </div>
      </div>
      <!--
      <div class="modal-footer">
        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
      </div>
      -->
    </div>

  </div>
</div>
<script src="//ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js"></script>
<script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
<script>
$(document).ready(function() {
    var $form = $('#edit_staff_form'),
        $modal = $('#edit-create-modal');

    $('.delete-staff').click(function(evt) {
        evt.preventDefault();
        var $tr = $(this).parents('tr'),
            workerID = $tr.find('[data-field="worker_id"]').text().trim();
        if (confirm("Are you sure you wish to delete this staff member?")) {
            $('#delete_worker_id').val(workerID);
            $('#delete_staff_form').get(0).submit();
        }
    });

    $('.edit-staff').click(function(evt) {
        evt.preventDefault();

        $modal.find('.modal-title').text('Edit Staff');
        $form.find('[name=action]').val('edit');

        var $tr = $(this).parents('tr');
        $tr.find('[data-field]').each(function(i, el) {
            var $el = $(el),
                key = $el.data('field');

            $form.find(`[name="${key}"]`).val($el.text());
        });
    });

    $('#add-staff').click(function(evt) {
        evt.preventDefault();

        $form.get(0).reset();
        $modal.find('.modal-title').text('Add Staff Member');
        $form.find('[name=action]').val('add');
    })
});
</script>
</body>
</html>
