<?php
require_once __DIR__ . '/../lib/class.db.php';
require_once __DIR__ . '/../lib/class.portal.php';
require_once __DIR__ . '/../vendor/autoload.php';

use RhdEvents\Portal as Portal;

session_start();

$db = new \RhdEvents\Db();

if (isset($_POST['worker_id'])) {
    $v = new Valitron\Validator($_POST);
    $v->rule('required', [
        'worker_id',
        'date',
        'start_time',
        'end_time',
        'description'
    ]);
    $v->rule('date', ['date', 'start_time', 'end_time']);

    if (!$v->validate()) {
        foreach($v->errors() as $err) {
            Portal::addFlashMessage($err, 'danger');
        }
        Portal::refresh();
        // exit
    }

    $workerID = $_POST['worker_id'];
    $date = $_POST['date'];
    $startTime = new \DateTime($date . ' ' . $_POST['start_time']);
    $endTime = new \DateTime($date . ' ' . $_POST['end_time']);

    try {
        $insertResult = $db->insert('work_logs', [
            'worker_id'         =>  $workerID,
            'start_datetime'    =>  $startTime->format('Y-m-d H:i:s'),
            'end_datetime'      =>  $endTime->format('Y-m-d H:i:s'),
            'description'       =>  $_POST['description'],
        ]);
        $db->wasActionSuccessful($insertResult);
        Portal::addFlashMessage("You time entry was successfully recorded", 'success');
        header("Location: /time-entries.php?start_date=" . $startTime->modify('-2 weeks')->format('Y-m-d'));
        exit;
    }
    catch (\Exception $e) {
        Portal::addFlashMessage($e->getMessage(), 'danger');
        Portal::refresh();
    }
    

}

require_once __DIR__ . '/../lib/inc.header.php';
?>

    <form method='POST'>
        <div class='row'>
            <div class='col-xs-12 col-md-offset-2 col-md-8'>
                <div class='form-group'>
                    <label>Staff</label>
                    <select name='worker_id' class='form-control' required>
                        <option>Select Staff Member</option>
<?php   
$workers = $db->select('workers', '*', ['active' => true]);
foreach($workers as $worker) {
    ?>
                        <option value='<?= $worker['worker_id'] ?>'><?= $worker['first_name'] ?> <?= $worker['last_name'] ?></option>
    <?php
}
?>
                    </select>
                </div>
            </div>
        </div>
        <div class='row'>
            <div class='col-xs-12 col-md-offset-2 col-md-8'>
                <div class="form-group">
                    <label>Date</label>
                    <div class='input-group date' id='date'>
                        <input type='text' class="form-control" name='date' required/>
                        <span class="input-group-addon">
                            <span class="glyphicon glyphicon-calendar"></span>
                        </span>
                    </div>
                </div>
            </div>
        </div>
        <div class='row'>
            <div class='col-xs-12 col-md-offset-2 col-md-8'>
                <div class="form-group">
                    <label>Start Time</label>
                    <div class='input-group time' id='start_time'>
                        <input type='text' class="form-control" name="start_time" required />
                        <span class="input-group-addon">
                            <span class="glyphicon glyphicon-time"></span>
                        </span>
                    </div>
                </div>
            </div>
        </div>
        <div class='row'>
            <div class='col-xs-12 col-md-offset-2 col-md-8'>
                <div class="form-group">
                    <label>End Time</label>
                    <div class='input-group time' id='end_time'>
                        <input type='text' class="form-control" name='end_time' required />
                        <span class="input-group-addon">
                            <span class="glyphicon glyphicon-time"></span>
                        </span>
                    </div>
                </div>
            </div>
        </div>

        <div class='row'>
            <div class='col-xs-12 col-md-offset-2 col-md-8'>
                <div class="form-group">
                    <label>Description of Work Performed</label>
                    <textarea class='form-control' name='description' required></textarea>
                </div>
            </div>
        </div>

        <div class='row'>
            <div class='col-xs-12 col-md-offset-2 col-md-8 text-center'>
                <button type='submit' class='btn btn-lg btn-primary'>Submit</button>
            </div>
        </div>
    </form>
</div>
<script src="//ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js"></script>
<script src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.5/js/bootstrap.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/moment.js/2.24.0/moment.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/bootstrap-datetimepicker/4.17.47/js/bootstrap-datetimepicker.min.js"></script>
<script>
$(document).ready(function(){
    $('#date').datetimepicker({
        format: 'L'
    });
    $('.time').datetimepicker({
        format: 'LT'
    });
});
</script>
</body>
</html>

